Run a simple simulation with online plot
========================================

These scripts are examples of how one can run small simulations with
instantaneous plotting. This can be useful for simple tests. The first script
can be launched by the commands ``python simul_ns2d_plotphys.py`` (sequential).

.. literalinclude:: simul_ns2d_plotphys.py

.. raw:: html

   <iframe width="560" height="315" 
           src="https://www.youtube.com/embed/FrvoTYSeKW8?rel=0" 
           frameborder="0" allow="autoplay; encrypted-media" allowfullscreen>
   </iframe>

The second script is dedicated to online plotting of statistic quantities.

.. literalinclude:: simul_ns2d_plot.py




